==> qtjambi-dbus-debuginfo-macos-6.6.1.jar: sources/QtJambiDBus/QDBusVariant_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtDBus/qdbusextratypes.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDBusVariant(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDBusVariant")
    QDBusVariant *_ptr = reinterpret_cast<QDBusVariant *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDBusVariant()
void __qt_construct_QDBusVariant_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDBusVariant()")
    Q_UNUSED(__java_arguments)
    QDBusVariant *__qt_this = new(__qtjambi_ptr) QDBusVariant();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QDBusVariant(QVariant)
void __qt_construct_QDBusVariant_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDBusVariant(QVariant)")
    jobject variant0 = __java_arguments[0].l;
    QVariant  __qt_variant0 = qtjambi_cast<QVariant >(__jni_env, variant0);
    QDBusVariant *__qt_this = new(__qtjambi_ptr) QDBusVariant(__qt_variant0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QDBusVariant
void __qt_destruct_QDBusVariant(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDBusVariant")
    reinterpret_cast<QDBusVariant*>(ptr)->~QDBusVariant();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDBusVariant::QDBusVariant()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusVariant_initialize_1native__Lio_qt_dbus_QDBusVariant_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusVariant::QDBusVariant()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDBusVariant_0, sizeof(QDBusVariant), typeid(QDBusVariant), false, &deleter_QDBusVariant, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusVariant::QDBusVariant(QVariant)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusVariant_initialize_1native__Lio_qt_dbus_QDBusVariant_2Ljava_lang_Object_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject variant0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusVariant::QDBusVariant(QVariant)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = variant0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDBusVariant_1, sizeof(QDBusVariant), typeid(QDBusVariant), false, &deleter_QDBusVariant, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusVariant::operator==(QDBusVariant,QDBusVariant)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusVariant_equals_1native_1cref_1QDBusVariant__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID v21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QDBusVariant *__qt_this = QtJambiAPI::objectFromNativeId<QDBusVariant>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusVariant::operator==(QDBusVariant,QDBusVariant)", __qt_this)
        const QDBusVariant& __qt_v21 = QtJambiAPI::objectReferenceFromNativeId<QDBusVariant>(__jni_env, v21);
        __java_return_value = (*__qt_this) == __qt_v21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusVariant::setVariant(QVariant)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusVariant_setVariant_1native_1cref_1QVariant__JLjava_lang_Object_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject variant0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDBusVariant *__qt_this = QtJambiAPI::objectFromNativeId<QDBusVariant>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusVariant::setVariant(QVariant)", __qt_this)
        QVariant  __qt_variant0 = qtjambi_cast<QVariant >(__jni_env, variant0);
        __qt_this->setVariant(__qt_variant0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusVariant::swap(QDBusVariant&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusVariant_swap_1native_1ref_1QDBusVariant__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDBusVariant *__qt_this = QtJambiAPI::objectFromNativeId<QDBusVariant>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusVariant::swap(QDBusVariant&)", __qt_this)
        QDBusVariant& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QDBusVariant>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusVariant::variant()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusVariant_variant_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusVariant *__qt_this = QtJambiAPI::objectFromNativeId<QDBusVariant>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusVariant::variant()const", __qt_this)
        QVariant __qt_return_value = __qt_this->variant();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusVariant_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDBusVariant *__qt_this = QtJambiAPI::objectFromNativeId<QDBusVariant>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDBusVariant(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDBusVariant>("QDBusVariant", "io/qt/dbus/QDBusVariant");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDBusVariant, {
        ConstructorInfo(&__qt_construct_QDBusVariant_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QDBusVariant_1, "Ljava/lang/Object;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDBusVariant);
    registerMetaType<QDBusVariant>("QDBusVariant");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-dbus-debuginfo-macos-6.6.3.jar: sources/QtJambiDBus/QDBusVariant_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtDBus/qdbusextratypes.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDBusVariant(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDBusVariant")
    QDBusVariant *_ptr = reinterpret_cast<QDBusVariant *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDBusVariant()
void __qt_construct_QDBusVariant(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDBusVariant()")
    Q_UNUSED(__java_arguments)
    QDBusVariant *__qt_this = new(__qtjambi_ptr) QDBusVariant();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QDBusVariant::QDBusVariant()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusVariant_initialize_1native__Lio_qt_dbus_QDBusVariant_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusVariant::QDBusVariant()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDBusVariant, sizeof(QDBusVariant), typeid(QDBusVariant), false, &deleter_QDBusVariant, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDBusVariant(QDBusVariant)
void __qt_construct_QDBusVariant_cref_QDBusVariant(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDBusVariant(QDBusVariant)")
    jobject other0 = __java_arguments[0].l;
    const QDBusVariant& __qt_other0 = qtjambi_cast<const QDBusVariant& >(__jni_env, other0);
    QDBusVariant *__qt_this = new(__qtjambi_ptr) QDBusVariant(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QDBusVariant::QDBusVariant(QDBusVariant)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusVariant_initialize_1native__Lio_qt_dbus_QDBusVariant_2Lio_qt_dbus_QDBusVariant_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusVariant::QDBusVariant(QDBusVariant)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDBusVariant_cref_QDBusVariant, sizeof(QDBusVariant), typeid(QDBusVariant), false, &deleter_QDBusVariant, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDBusVariant(QVariant)
void __qt_construct_QDBusVariant_cref_QVariant(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDBusVariant(QVariant)")
    jobject variant0 = __java_arguments[0].l;
    QVariant  __qt_variant0 = qtjambi_cast<QVariant >(__jni_env, variant0);
    QDBusVariant *__qt_this = new(__qtjambi_ptr) QDBusVariant(__qt_variant0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QDBusVariant::QDBusVariant(QVariant)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusVariant_initialize_1native__Lio_qt_dbus_QDBusVariant_2Ljava_lang_Object_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject variant0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusVariant::QDBusVariant(QVariant)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = variant0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDBusVariant_cref_QVariant, sizeof(QDBusVariant), typeid(QDBusVariant), false, &deleter_QDBusVariant, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDBusVariant
void __qt_destruct_QDBusVariant(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDBusVariant")
    reinterpret_cast<QDBusVariant*>(ptr)->~QDBusVariant();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDBusVariant::operator==(QDBusVariant,QDBusVariant)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusVariant_equals_1native_1cref_1QDBusVariant__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID v21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QDBusVariant *__qt_this = QtJambiAPI::objectFromNativeId<QDBusVariant>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusVariant::operator==(QDBusVariant,QDBusVariant)", __qt_this)
        const QDBusVariant& __qt_v21 = QtJambiAPI::objectReferenceFromNativeId<QDBusVariant>(__jni_env, v21);
        __java_return_value = (*__qt_this) == __qt_v21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusVariant::setVariant(QVariant)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusVariant_setVariant_1native_1cref_1QVariant__JLjava_lang_Object_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject variant0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDBusVariant *__qt_this = QtJambiAPI::objectFromNativeId<QDBusVariant>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusVariant::setVariant(QVariant)", __qt_this)
        QVariant  __qt_variant0 = qtjambi_cast<QVariant >(__jni_env, variant0);
        __qt_this->setVariant(__qt_variant0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusVariant::swap(QDBusVariant&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusVariant_swap_1native_1ref_1QDBusVariant__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDBusVariant *__qt_this = QtJambiAPI::objectFromNativeId<QDBusVariant>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusVariant::swap(QDBusVariant&)", __qt_this)
        QDBusVariant& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QDBusVariant>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusVariant::variant()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusVariant_variant_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusVariant *__qt_this = QtJambiAPI::objectFromNativeId<QDBusVariant>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusVariant::variant()const", __qt_this)
        QVariant __qt_return_value = __qt_this->variant();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusVariant_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDBusVariant *__qt_this = QtJambiAPI::objectFromNativeId<QDBusVariant>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDBusVariant(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDBusVariant>("QDBusVariant", "io/qt/dbus/QDBusVariant");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDBusVariant, {
        ConstructorInfo(&__qt_construct_QDBusVariant, nullptr)
       ,ConstructorInfo(&__qt_construct_QDBusVariant_cref_QDBusVariant, "Lio/qt/dbus/QDBusVariant;")
       ,ConstructorInfo(&__qt_construct_QDBusVariant_cref_QVariant, "Ljava/lang/Object;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDBusVariant);
    registerMetaType<QDBusVariant>("QDBusVariant");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
